#
# spec file for package jikes
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{!?make_build:%global make_build make %{?_smp_mflags}}
Name:           jikes
Version:        1.22
Release:        161.4
Summary:        IBM Java Compiler
License:        IPL-1.0
Group:          Development/Languages/Java
URL:            https://jikes.sourceforge.net/
Source0:        %{name}-%{version}.tar.bz2
Patch0:         %{name}-%{version}-uninitialized-variables.patch
Patch1:         %{name}-%{version}-strict_aliasing.patch
BuildRequires:  automake
BuildRequires:  gcc-c++
Requires:       jre >= 1.1

%description
Jikes(TM) is a compiler that translates Java(TM) source files as
defined in "The Java Language Specification" into the byte code
instruction set and binary format defined in "The Java Virtual Machine
Specification."

You may wonder why the world needs another Java compiler, considering
that Sun provides javac free with its SDK. Jikes has four advantages
that make it a valuable contribution to the Java community:

* Open source. Jikes is OSI Certified Open Source Software. OSI
   Certified is a certification mark of the Open Source Initiative.

* Strictly Java compatible. Jikes strives to adhere to both "The
   Java Language Specification" and "The Java Virtual Machine
   Specification" as tightly as possible and does not support
   subsets, supersets, or other variations of the language. The FAQ
   describes some of the side effects of this strict language
   conformance.

* High performance. Jikes is a high performance compiler, making it
   ideal for use with larger projects.

* Dependency analysis. Jikes performs a dependency analysis on your
   code that provides two very useful features: Incremental builds
   and makefile generation.

Note that you must set CLASSPATH correctly to use jikes.

%prep
%setup -q
%patch -P 0
%patch -P 1
cp -v  doc/license.htm license.html

%build
autoreconf -I src/m4 --force --install
CFLAGS="%{optflags}" \
CXXFLAGS="%{optflags}" \
%configure --mandir=%{_mandir} \
           --prefix=%{_prefix} \
           --infodir=%{_infodir} \
           --sysconfdir=%{_sysconfdir}
%make_build

%install
%make_install
#
rm %{buildroot}/%{_datadir}/doc/%{name}-%{version}/license.htm

%files
%license COPYING doc/license.htm
%doc AUTHORS ChangeLog NEWS README TODO
%{_mandir}/man1/jikes.1%{?ext_man}
%{_includedir}/*
%{_bindir}/jikes

%changelog
* Wed Feb 21 2024 Fridrich Strba <fstrba@suse.com>
- Use %%patch -P N instead of deprecated %%patchN.
* Mon Oct 30 2017 fstrba@suse.com
- With removal of java-1_5_0-gcj-compat, jikes became uninstallable
  * Require: jre1.1.x -> jre >= 1.1
- Spec cleaner
* Wed Dec 21 2011 coolo@suse.com
- remove call to suse_update_config (very old work around)
* Fri Dec  2 2011 coolo@suse.com
- add automake as buildrequire to avoid implicit dependency
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Mon Dec 19 2005 dbornkessel@suse.de
- minor adjustments to avoid "strict aliasing" and "uninitialized variables" warnings
* Fri Feb 18 2005 skh@suse.de
- updated to version 1.22:
  * supports compilation using the rt.jar shipped with the
    released version of Java 5.0
* Wed Sep  1 2004 pmladek@suse.cz
- updated to version 1.21
  * correctly detects an attempt to use a non-static member class from a
    static one, without proper qualification
  * new command-line options generalize the old -nowarn/+Z
  * the default on vs. off state of several warnings added in 1.19 have been
    changed, by popular demand
  * etc., see /usr/share/doc/packages/jikes/NEWS for more details
- enabled parallel build
- used autoreconf instead of the single utils like aclocal, automake
- removed the unneeded file INSTALL from documentation
* Wed Mar  3 2004 pmladek@suse.cz
- updated to version 1.19
- m4 marcos are included in the original source tar-ball again
- removed obsolete patch which fixed aclocal.m4
- fixed usage of aclocal
- used %%%%_prefix and %%%%_sysconfdir macros
* Sat Jan 10 2004 adrian@suse.de
- build as user
* Tue May 27 2003 pmladek@suse.cz
- removed license.htm from buildroot (it is packaged another way)
* Wed Feb  5 2003 novak@suse.cz
- updated to version 1.18
- updated m4 macros from CVS
* Wed Aug  7 2002 pmladek@suse.cz
- updated to version 1.16
- updated m4 macros from CVS
- removed obsolete axp patch (it is fixed in this version)
- removed obsolete ia64 patch (it is no longer needed)
* Wed Dec 12 2001 pmladek@suse.cz
- updated to version 1.15, bugfix release
- updated m4 macros from CVS
- removed obsolete namespace patch, gcc works now
- added /usr/include/jikesapi.h to filelist
* Fri Nov  9 2001 pmladek@suse.cz
- fixed to compile with automake 1.5
* Thu Sep 20 2001 pmladek@suse.cz
- fixed requires - jikes works with all javas
* Mon Aug 13 2001 pmladek@suse.cz
- fixed to compile on i386:
  * compiled with namespace on
- fixed to compile on ia64:
  * added sources of autoconf macros from jikes CVS
  * ugly fix through bug in autoconf
- fixed to compile on axp:
  * renamed variable NAN which is defined as macro in math.h
- cleaned up specfile
* Fri May 18 2001 pblaha@suse.cz
- upadte on 1.14
* Wed Nov 29 2000 aj@suse.de
- Fix for compilation with glibc 2.2.
* Wed Sep 20 2000 smid@suse.cz
- upgrade to 1.12
* Thu Jun  8 2000 cihlar@suse.cz
- added %%clean
* Thu Apr 20 2000 smid@suse.cz
- add documentation which was unfortunetly removed
* Thu Apr 20 2000 smid@suse.cz
- buildroot added
* Mon Jan 17 2000 aj@suse.de
- /usr/man -> /usr/share/man
* Wed Oct 20 1999 aj@suse.de
- Fixed configure and make calls.
* Tue Oct 19 1999 aj@suse.de
- Added a require for java_runtime, updated pac file.
* Tue Oct 19 1999 aj@suse.de
- created package (version 1.06)
